@@ -59,7 +59,7 @@ from pysollib.resource import Music, MusicManager
 from pysollib.resource import Sample, SampleManager
 from pysollib.resource import Tile, TileManager
 from pysollib.settings import DEBUG
-from pysollib.settings import PACKAGE, VERSION_TUPLE, WIN_SYSTEM
+from pysollib.settings import PACKAGE, VERSION_TUPLE  # , WIN_SYSTEM
 from pysollib.settings import TOOLKIT
 from pysollib.util import IMAGE_EXTENSIONS
 from pysollib.winsystems import TkSettings
@@ -509,10 +509,11 @@ class Application:
                   "joker11_100_774",
                   "joker10_100",):
             self.gimages.logos.append(self.dataloader.findImage(f, dirname))
-        if WIN_SYSTEM == 'win32':
-            dirname = os.path.join('images', 'dialog', 'default')
-        else:
-            dirname = os.path.join('images', 'dialog', 'bluecurve')
+        # if WIN_SYSTEM == 'win32':
+        #     dirname = os.path.join('images', 'dialog', 'default')
+        # else:
+        #     dirname = os.path.join('images', 'dialog', 'bluecurve')
+        dirname = os.path.join('images', 'dialog', 'remix')
         for f in ('error', 'info', 'question', 'warning'):
             fn = self.dataloader.findImage(f, dirname)
             im = loadImage(fn)
@@ -585,14 +586,16 @@ class Application:
         return self._getImagesDir('cards')
 
     def getToolbarImagesDir(self):
-        if self.opt.toolbar_size:
+        if self.opt.toolbar_size == 2:
+            size = 'xlarge'
+        elif self.opt.toolbar_size == 1:
             size = 'large'
         else:
             size = 'small'
         style = self.opt.toolbar_style
         if TOOLKIT == 'kivy':
             size = 'xlarge'
-            style = 'bluecurve'
+            style = 'remix light'
         d = self._getImagesDir('toolbar', style, size)
         if d:
             return d
@@ -614,6 +617,19 @@ class Application:
     def getFont(self, name):
         return self.opt.fonts.get(name)
 
+    #
+    # search logic
+    #
+
+    def checkSearchString(self, search_string, check_string):
+        terms = search_string.split()
+        if len(terms) == 0:
+            return True
+        for term in terms:
+            if term.upper() not in check_string.upper():
+                return False
+        return True
+
     #
     # cardset
     #
@@ -681,6 +697,7 @@ class Application:
                                         color=color,
                                         images=self.progress_images)
         images = Images(self.dataloader, cs)
+        images.cardset_bottoms = self.opt.use_cardset_bottoms
         try:
             if not images.load(app=self, progress=progress):
                 raise Exception("Invalid or damaged cardset")
@@ -1252,9 +1269,9 @@ class Application:
         self.initResource(manager, dirs, ext_re, Sample)
 
     def initMusic(self):
-        manager = self.music_manager
+        music_manager = self.music_manager
         # find all available music songs
-        dirs = manager.getSearchDirs(self, "music-*", "PYSOL_MUSIC")
-        # print dirs
+        dirs = music_manager.getSearchDirs(self, "music-*", "PYSOL_MUSIC")
+        # print('dirs =', dirs)
         ext_re = re.compile(self.audio.EXTENSIONS)
-        self.initResource(manager, dirs, ext_re, Music)
+        self.initResource(music_manager, dirs, ext_re, Music)
