@@ -56,11 +56,13 @@ from . import headsandtails  # noqa: F401
 from . import hitormiss  # noqa: F401
 from . import katzenschwanz  # noqa: F401
 from . import klondike  # noqa: F401
+from . import knockout  # noqa: F401
 from . import labyrinth  # noqa: F401
 from . import larasgame  # noqa: F401
 from . import matriarchy  # noqa: F401
 from . import montana  # noqa: F401
 from . import montecarlo  # noqa: F401
+from . import moojub  # noqa: F401
 from . import napoleon  # noqa: F401
 from . import needle  # noqa: F401
 from . import numerica  # noqa: F401
