@@ -21,29 +21,27 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import ACE, KING, NO_RANK, UNLIMITED_ACCEPTS, \
-        UNLIMITED_MOVES
+from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.hint import CautiousDefaultHint
+from pysollib.hint import FreeCellSolverWrapper
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
 from pysollib.stack import \
         AC_FoundationStack, \
         AC_RowStack, \
         InitialDealTalonStack, \
+        InvisibleStack, \
         RK_RowStack, \
         SS_FoundationStack, \
         SS_RowStack, \
+        StackWrapper, \
         SuperMoveAC_RowStack, \
         TalonStack, \
         UD_AC_RowStack, \
-        UD_SS_RowStack, \
-        StackWrapper
-from pysollib.mfxutil import kwdefault
-from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import CautiousDefaultHint
-from pysollib.hint import FreeCellSolverWrapper
+        UD_SS_RowStack
+from pysollib.util import ACE, KING, NO_RANK, UNLIMITED_ACCEPTS, \
+        UNLIMITED_MOVES
 
 
 # ************************************************************************
@@ -58,6 +56,8 @@ class CastlesInSpain(Game):
     Hint_Class = CautiousDefaultHint
     Solver_Class = FreeCellSolverWrapper()
 
+    GAME_VERSION = 2
+
     #
     # game layout
     #
@@ -76,6 +76,7 @@ class CastlesInSpain(Game):
         for r in l.s.rows:
             s.rows.append(self.RowStack_Class(r.x, r.y, self))
         # default
+        self.s.internals.append(InvisibleStack(self))
         l.defaultAll()
         return l
 
@@ -199,6 +200,7 @@ class GoodMeasure(BakersDozen):
 
 # ************************************************************************
 # * Cruel
+# * Unusual
 # ************************************************************************
 
 class Cruel_Talon(TalonStack):
@@ -216,14 +218,24 @@ class Cruel_Talon(TalonStack):
         num_cards = 0
         assert len(self.cards) == 0
         rows = list(self.game.s.rows)[:]
-        rows.reverse()
+        # rows.reverse()
         for r in rows:
             for i in range(len(r.cards)):
                 num_cards = num_cards + 1
-                self.game.moveMove(1, r, self, frames=0)
+                self.game.moveMove(1, r, self.game.s.internals[0], frames=0)
+
+        if len(self.game.s.internals[0].cards) % 4 != 0:
+            self.game.moveMove(len(self.game.s.internals[0].cards) % 4,
+                               self.game.s.internals[0], self, frames=0)
+
+        while len(self.game.s.internals[0].cards) > 0:
+            self.game.moveMove(4, self.game.s.internals[0], self, frames=0)
+
         assert len(self.cards) == num_cards
+
         if num_cards == 0:          # game already finished
             return 0
+
         # redeal in packs of 4 cards
         self.game.nextRoundMove(self)
         n, i = num_cards, 0
@@ -252,7 +264,9 @@ class Cruel_Talon(TalonStack):
 
 class Cruel(CastlesInSpain):
     Talon_Class = StackWrapper(Cruel_Talon, max_rounds=-1)
-    RowStack_Class = StackWrapper(SS_RowStack, base_rank=NO_RANK)
+    RowStack_Class = StackWrapper(SS_RowStack,
+                                  max_move=1, max_accept=1, base_rank=NO_RANK)
+
     # Solver_Class = FreeCellSolverWrapper(preset='cruel')
     Solver_Class = None
 
@@ -271,6 +285,12 @@ class Cruel(CastlesInSpain):
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
 
+class Unusual(Cruel):
+
+    def createGame(self):
+        return CastlesInSpain.createGame(self, rows=24)
+
+
 # ************************************************************************
 # * Royal Family
 # * Indefatigable
@@ -356,6 +376,7 @@ class RippleFan(CastlesInSpain):
         for r in l.s.rows:
             s.rows.append(SS_RowStack(r.x, r.y, self, base_rank=NO_RANK))
         # default
+        self.s.internals.append(InvisibleStack(self))
         l.defaultAll()
 
     def startGame(self):
@@ -389,10 +410,13 @@ registerGame(GameInfo(308, PortugueseSolitaire, "Portuguese Solitaire",
 registerGame(GameInfo(404, Perseverance, "Perseverance",
                       GI.GT_BAKERS_DOZEN | GI.GT_OPEN, 1, 2, GI.SL_BALANCED))
 registerGame(GameInfo(369, RippleFan, "Ripple Fan",
-                      GI.GT_BAKERS_DOZEN, 1, -1, GI.SL_MOSTLY_SKILL))
+                      GI.GT_BAKERS_DOZEN | GI.GT_OPEN, 1, -1,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(515, Indefatigable, "Indefatigable",
                       GI.GT_BAKERS_DOZEN | GI.GT_OPEN, 1, 2,
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(664, SpanishPatienceII, "Spanish Patience II",
                       GI.GT_BAKERS_DOZEN | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(823, Unusual, "Unusual",
+                      GI.GT_BAKERS_DOZEN | GI.GT_OPEN, 2, -1, GI.SL_BALANCED))
