@@ -21,39 +21,32 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import ACE, ANY_RANK, NO_RANK, KING, QUEEN, RANKS
+from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.hint import CautiousDefaultHint, FreeCellType_Hint
+from pysollib.hint import FreeCellSolverWrapper
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
+from pysollib.pysoltk import MfxCanvasText
 from pysollib.stack import \
         InitialDealTalonStack, \
         OpenStack, \
-        ReserveStack, \
         RK_FoundationStack, \
         RK_RowStack, \
-        Spider_SS_RowStack, \
+        ReserveStack, \
         SS_FoundationStack, \
+        Spider_SS_RowStack, \
+        StackWrapper, \
         SuperMoveRK_RowStack, \
         TalonStack, \
         UD_AC_RowStack, \
         UD_RK_RowStack, \
         UD_SS_RowStack, \
         WasteStack, \
-        WasteTalonStack, \
-        StackWrapper
-from pysollib.mfxutil import kwdefault
-from pysollib.game import Game
-from pysollib.layout import Layout
-from pysollib.hint import CautiousDefaultHint, FreeCellType_Hint
-from pysollib.hint import FreeCellSolverWrapper
-from pysollib.pysoltk import MfxCanvasText
+        WasteTalonStack
+from pysollib.util import ACE, ANY_RANK, KING, NO_RANK, QUEEN, RANKS
 
 
-# ************************************************************************
-# *
-# ************************************************************************
-
 class BeleagueredCastleType_Hint(CautiousDefaultHint):
     # FIXME: demo is not too clever in this game
     pass
@@ -431,10 +424,19 @@ class Chessboard(Fortress):
 
 
 # ************************************************************************
+# * Siegecraft
 # * Stronghold
 # * Fastness
 # ************************************************************************
 
+class Siegecraft(BeleagueredCastle):
+    Hint_Class = FreeCellType_Hint
+    Solver_Class = FreeCellSolverWrapper(sbb='rank')
+
+    def createGame(self):
+        BeleagueredCastle.createGame(self, reserves=1)
+
+
 class Stronghold(StreetsAndAlleys):
     Hint_Class = FreeCellType_Hint
     Solver_Class = FreeCellSolverWrapper(sbb='rank')
@@ -871,7 +873,8 @@ registerGame(GameInfo(146, StreetsAndAlleys, "Streets and Alleys",
                       GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(34, BeleagueredCastle, "Beleaguered Castle",
                       GI.GT_BELEAGUERED_CASTLE | GI.GT_OPEN, 1, 0,
-                      GI.SL_MOSTLY_SKILL))
+                      GI.SL_MOSTLY_SKILL,
+                      altnames=("Laying Siege", "Sham Battle",)))
 registerGame(GameInfo(145, Citadel, "Citadel",
                       GI.GT_BELEAGUERED_CASTLE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL))
@@ -926,3 +929,6 @@ registerGame(GameInfo(650, CastlesEnd, "Castles End",
 registerGame(GameInfo(665, PenelopesWeb, "Penelope's Web",
                       GI.GT_BELEAGUERED_CASTLE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(831, Siegecraft, "Siegecraft",
+                      GI.GT_BELEAGUERED_CASTLE | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_SKILL))
