@@ -300,6 +300,7 @@ class Backbone_BraidStack(OpenStack):
 
 
 class Backbone(Game):
+    RESERVE_CARDS = 11
 
     Hint_Class = CautiousDefaultHint
 
@@ -309,7 +310,8 @@ class Backbone(Game):
 
         # set window
         w, h = l.XM+(rows+2)*l.XS, max(
-            l.YM+3*l.XS+10*l.YOFFSET, l.YM+2*l.YS+11*l.YOFFSET+l.TEXT_HEIGHT)
+            l.YM + 3 * l.XS + 10 * l.YOFFSET,
+            l.YM + 2 * l.YS + self.RESERVE_CARDS * l.YOFFSET + l.TEXT_HEIGHT)
         self.setSize(w, h)
 
         # create stacks
@@ -324,7 +326,7 @@ class Backbone(Game):
         s.reserves.append(Backbone_BraidStack(x, y, self, max_accept=0))
         x += l.XS
         s.reserves.append(Backbone_BraidStack(x, y, self, max_accept=0))
-        x, y = l.XM+(rows+1)*l.XS//2, l.YM+11*l.YOFFSET
+        x, y = l.XM+(rows+1)*l.XS//2, l.YM+self.RESERVE_CARDS*l.YOFFSET
         s.reserves.append(BasicRowStack(x, y, self, max_accept=0))
 
         x, y = l.XM, l.YM+l.YS
@@ -347,7 +349,7 @@ class Backbone(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        for i in range(10):
+        for i in range(self.RESERVE_CARDS - 1):
             self.s.talon.dealRow(rows=self.s.reserves[:2], frames=0)
         self.s.talon.dealRow(rows=self.s.reserves, frames=0)
         self.startDealSample()
@@ -362,6 +364,10 @@ class BackbonePlus(Backbone):
         Backbone.createGame(self, rows=10)
 
 
+class SmallBackbone(Backbone):
+    RESERVE_CARDS = 9
+
+
 # ************************************************************************
 # * Big Braid
 # ************************************************************************
@@ -644,3 +650,5 @@ registerGame(GameInfo(694, Casket, "Casket",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(717, Well, "Well",
                       GI.GT_2DECK_TYPE, 2, 4, GI.SL_BALANCED))
+registerGame(GameInfo(824, SmallBackbone, "Small Backbone",
+                      GI.GT_NAPOLEON, 2, 0, GI.SL_BALANCED))
