@@ -1,46 +1,52 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
-__all__ = []
-
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.stack import *
 from pysollib.game import Game
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.games.numerica import Numerica_Hint
+from pysollib.hint import AbstractHint, CautiousDefaultHint
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
+from pysollib.mygettext import _
 from pysollib.pysoltk import MfxCanvasText
-
-from numerica import Numerica_Hint
-
-
+from pysollib.stack import \
+        AbstractFoundationStack, \
+        BasicRowStack, \
+        OpenStack, \
+        OpenTalonStack, \
+        ReserveStack, \
+        SS_FoundationStack, \
+        SS_RowStack, \
+        StackWrapper, \
+        WasteStack, \
+        WasteTalonStack
+from pysollib.util import ACE, ANY_RANK, ANY_SUIT, JACK, KING, NO_RANK, \
+        QUEEN, RANKS, \
+        UNLIMITED_CARDS
 # ************************************************************************
 # * Camelot
 # ************************************************************************
 
+
 class Camelot_Hint(AbstractHint):
 
     def computeHints(self):
@@ -99,26 +105,32 @@ class Camelot_RowStack(ReserveStack):
             self.playMoveMove(1, game.s.foundations[0], sound=False)
             self.fillStack()
             return True
+        if not self.cards and game.s.talon.cards and \
+                self.acceptsCards(game.s.talon, [game.s.talon.cards[-1]]):
+            game.s.talon.playMoveMove(1, self)
+            return True
+
         return False
 
     def moveMove(self, ncards, to_stack, frames=-1, shadow=-1):
-        if not to_stack is self.game.s.foundations[0]:
+        if to_stack is not self.game.s.foundations[0]:
             self._dropPairMove(ncards, to_stack, frames=-1, shadow=shadow)
         else:
-            ReserveStack.moveMove(self, ncards, to_stack, frames=frames, shadow=shadow)
+            ReserveStack.moveMove(
+                self, ncards, to_stack, frames=frames, shadow=shadow)
 
     def _dropPairMove(self, n, other_stack, frames=-1, shadow=-1):
         game = self.game
         old_state = game.enterState(game.S_FILL)
         f = game.s.foundations[0]
-        game.updateStackMove(game.s.talon, 2|16)            # for undo
+        game.updateStackMove(game.s.talon, 2 | 16)            # for undo
         if not game.demo:
             game.playSample("droppair", priority=200)
         game.moveMove(n, self, f, frames=frames, shadow=shadow)
         game.moveMove(n, other_stack, f, frames=frames, shadow=shadow)
         self.fillStack()
         other_stack.fillStack()
-        game.updateStackMove(game.s.talon, 1|16)            # for redo
+        game.updateStackMove(game.s.talon, 1 | 16)            # for redo
         game.leaveState(old_state)
 
 
@@ -130,9 +142,9 @@ class Camelot_Foundation(AbstractFoundationStack):
 class Camelot_Talon(OpenTalonStack):
     def fillStack(self):
         old_state = self.game.enterState(self.game.S_FILL)
-        self.game.saveStateMove(2|16)            # for undo
+        self.game.saveStateMove(2 | 16)            # for undo
         self.game.is_fill = self.game.isRowsFill()
-        self.game.saveStateMove(1|16)            # for redo
+        self.game.saveStateMove(1 | 16)            # for redo
         self.game.leaveState(old_state)
         OpenTalonStack.fillStack(self)
 
@@ -157,11 +169,26 @@ class Camelot(Game):
         w = l.XS
         self.setSize(l.XM + w + 4*l.XS + w + l.XS, l.YM + 4*l.YS)
         # create stacks
+        stackNum = 0
+        font = self.app.getFont("canvas_default")
         for i in range(4):
             for j in range(4):
-                k = i+j*4
                 x, y = l.XM + w + j*l.XS, l.YM + i*l.YS
-                s.rows.append(self.RowStack_Class(x, y, self))
+                stack = self.RowStack_Class(x, y, self)
+                if self.preview <= 1:
+                    stack.texts.misc = MfxCanvasText(self.canvas,
+                                                     x + l.CW // 2,
+                                                     y + l.CH // 2,
+                                                     anchor="center",
+                                                     font=font)
+                    if stackNum in (0, 3, 12, 15):
+                        stack.texts.misc.config(text="K")
+                    elif stackNum in (1, 2, 13, 14):
+                        stack.texts.misc.config(text="Q")
+                    elif stackNum in (4, 7, 8, 11):
+                        stack.texts.misc.config(text="J")
+                s.rows.append(stack)
+                stackNum += 1
         x, y = l.XM, l.YM
         s.talon = self.Talon_Class(x, y, self)
         l.createText(s.talon, 's')
@@ -182,15 +209,15 @@ class Camelot(Game):
         self.is_fill = False
         self.s.talon.fillStack()
 
-
     def isGameWon(self):
         for i in (5, 6, 9, 10):
             if len(self.s.rows[i].cards) != 0:
                 return False
         return len(self.s.talon.cards) == 0
 
-
     def isRowsFill(self):
+        if len(self.s.talon.cards) == 0:
+            return True
         for i in range(16):
             if len(self.s.rows[i].cards) == 0:
                 return False
@@ -238,12 +265,13 @@ class SlyFox_Talon(OpenTalonStack):
 
     def moveMove(self, ncards, to_stack, frames=-1, shadow=-1):
         old_state = self.game.enterState(self.game.S_FILL)
-        self.game.saveStateMove(2|16)            # for undo
+        self.game.saveStateMove(2 | 16)            # for undo
         if old_state == self.game.S_PLAY and to_stack in self.game.s.rows:
             n = self.game.num_dealled
-            if n < 0: n = 0
-            self.game.num_dealled = (n+1)%20
-        self.game.saveStateMove(1|16)            # for redo
+            if n < 0:
+                n = 0
+            self.game.num_dealled = (n+1) % 20
+        self.game.saveStateMove(1 | 16)            # for redo
         self.game.leaveState(old_state)
         OpenTalonStack.moveMove(self, ncards, to_stack, frames, shadow)
 
@@ -292,10 +320,11 @@ class SlyFox(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
-        return self._shuffleHookMoveToTop(cards,
-           lambda c: (c.rank in (ACE, KING) and c.deck == 0, (c.suit, c.rank)))
+        return self._shuffleHookMoveToTop(
+            cards,
+            lambda c: (c.rank in (ACE, KING) and c.deck == 0,
+                       (c.suit, c.rank)))
 
     def startGame(self):
         self.num_dealled = -1
@@ -321,20 +350,19 @@ class SlyFox(Game):
         # save vars (for undo/redo)
         return [self.num_dealled]
 
-
     def fillStack(self, stack):
         if self.num_dealled == -1 and stack in self.s.rows and not stack.cards:
             old_state = self.enterState(self.S_FILL)
             self.s.talon.moveMove(1, stack)
             self.leaveState(old_state)
 
-
     def updateText(self):
         if self.preview > 1:
             return
         n = self.num_dealled
-        if n < 0: n = 0
-        text=str(n)+'/20'
+        if n < 0:
+            n = 0
+        text = str(n)+'/20'
         self.texts.misc.config(text=text)
 
 
@@ -344,7 +372,8 @@ class OpenSlyFox(SlyFox):
         playcards = 6
 
         l, s = Layout(self), self.s
-        self.setSize(l.XM+10*l.XS, l.YM+3*l.YS+2*playcards*l.YOFFSET+l.TEXT_HEIGHT)
+        self.setSize(
+            l.XM+10*l.XS, l.YM+3*l.YS+2*playcards*l.YOFFSET+l.TEXT_HEIGHT)
 
         x, y = l.XM, l.YM
         s.talon = SlyFox_Talon(x, y, self)
@@ -383,16 +412,17 @@ class PrincessPatience_RowStack(SS_RowStack):
     def canMoveCards(self, cards):
         if not SS_RowStack.canMoveCards(self, cards):
             return False
-        ##index = list(self.game.s.rows).index(self) # don't work in demo-mode with cloned stack
+        # don't work in demo-mode with cloned stack
+        # index = list(self.game.s.rows).index(self)
         index = self.id
         col = index % 4
-        row = index / 4
-        if index < 16: # left
+        row = index // 4
+        if index < 16:  # left
             for i in range(col+1, 4):
                 r = self.game.s.rows[row*4+i]
                 if r.cards:
                     return False
-        else: # right
+        else:  # right
             for i in range(0, col):
                 r = self.game.s.rows[row*4+i]
                 if r.cards:
@@ -450,13 +480,11 @@ class PrincessPatience(Game):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow()
         self.s.talon.dealCards()
 
-
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
 
@@ -491,14 +519,16 @@ class GrandmammasPatience(Game):
 
         x, y = self.width-4*l.XS, l.YM
         for i in range(4):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i,
-                                 dir=-1, mod=13, max_move=0, base_rank=ANY_RANK))
+            s.foundations.append(
+                SS_FoundationStack(
+                    x, y, self, suit=i,
+                    dir=-1, mod=13, max_move=0, base_rank=ANY_RANK))
             x += l.XS
         stack = s.foundations[0]
         tx, ty, ta, tf = l.getTextAttr(stack, "sw")
         font = self.app.getFont("canvas_default")
-        stack.texts.misc = MfxCanvasText(self.canvas, tx, ty,
-                                        anchor=ta, font=font)
+        stack.texts.misc = MfxCanvasText(
+            self.canvas, tx, ty, anchor=ta, font=font)
         x, y = self.width-4*l.XS, self.height-l.YS
         for i in range(4):
             s.foundations.append(SS_FoundationStack(x, y, self, suit=i,
@@ -507,8 +537,8 @@ class GrandmammasPatience(Game):
         stack = s.foundations[4]
         tx, ty, ta, tf = l.getTextAttr(stack, "sw")
         font = self.app.getFont("canvas_default")
-        stack.texts.misc = MfxCanvasText(self.canvas,
-                                        tx, ty, anchor=ta, font=font)
+        stack.texts.misc = MfxCanvasText(
+            self.canvas, tx, ty, anchor=ta, font=font)
 
         y = l.YM+l.YS
         for i in range(2):
@@ -527,7 +557,6 @@ class GrandmammasPatience(Game):
         l.defaultStackGroups()
         self.sg.dropstacks.append(s.talon)
 
-
     def startGame(self):
         c = self.s.talon.cards[-1]
         self.base_rank = c.rank
@@ -537,12 +566,11 @@ class GrandmammasPatience(Game):
         for s in self.s.foundations[:4]:
             s.cap.base_rank = c.rank
         for s in self.s.foundations[4:]:
-            s.cap.base_rank = (c.rank+1)%13
+            s.cap.base_rank = (c.rank+1) % 13
         self.startDealSample()
         self.s.talon.dealRow()
         self.s.talon.fillStack()
 
-
     def fillStack(self, stack):
         if stack in self.s.rows and not stack.cards:
             if self.s.talon.cards:
@@ -558,17 +586,16 @@ class GrandmammasPatience(Game):
             t1 = t2 = ''
         else:
             t1 = RANKS[base_rank]+_(" Descending")
-            t2 = RANKS[(base_rank+1)%13]+_(" Ascending")
+            t2 = RANKS[(base_rank+1) % 13]+_(" Ascending")
         self.s.foundations[0].texts.misc.config(text=t1)
         self.s.foundations[4].texts.misc.config(text=t2)
 
-
     def _restoreGameHook(self, game):
         self.base_rank = game.loadinfo.base_rank
         for s in self.s.foundations[:4]:
             s.cap.base_rank = self.base_rank
         for s in self.s.foundations[4:]:
-            s.cap.base_rank = (self.base_rank+1)%13
+            s.cap.base_rank = (self.base_rank+1) % 13
 
     def _loadGameHook(self, p):
         self.loadinfo.addattr(base_rank=None)    # register extra load var.
@@ -578,7 +605,6 @@ class GrandmammasPatience(Game):
         p.dump(self.base_rank)
 
 
-
 # ************************************************************************
 # * Double Line
 # ************************************************************************
@@ -611,7 +637,7 @@ class DoubleLine(Game):
 
         x += l.XS
         for i in range(4):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i%4))
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i % 4))
             x += l.XS
         for i in range(4):
             s.foundations.append(SS_FoundationStack(x, y, self, suit=i,
@@ -646,16 +672,16 @@ class DoubleLine(Game):
 
 # register the game
 registerGame(GameInfo(280, Camelot, "Camelot",
-                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED))
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED,
+                      altnames=("Kings in the Corners")))
 registerGame(GameInfo(610, SlyFox, "Sly Fox",
                       GI.GT_NUMERICA, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(614, OpenSlyFox, "Open Sly Fox",
-                      GI.GT_NUMERICA | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_NUMERICA | GI.GT_ORIGINAL, 2, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(623, PrincessPatience, "Princess Patience",
                       GI.GT_2DECK_TYPE, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(622, GrandmammasPatience, "Grandmamma's Patience",
                       GI.GT_NUMERICA, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(702, DoubleLine, "Double Line",
                       GI.GT_NUMERICA, 2, 0, GI.SL_BALANCED))
-
-
