@@ -106,16 +106,20 @@ class Canfield(Game):
 
         # create stacks
         x, y = lay.XM, lay.YM
+        if round_text:
+            y += lay.TEXT_HEIGHT
         s.talon = self.Talon_Class(x, y, self,
                                    max_rounds=max_rounds, num_deal=num_deal)
         lay.createText(s.talon, "s")
         if round_text:
-            lay.createRoundText(s.talon, 'sss')
+            lay.createRoundText(s.talon, 'n')
         x += lay.XS
         s.waste = WasteStack(x, y, self)
         lay.createText(s.waste, "s")
         x += lay.XM
         y = lay.YM
+        if round_text:
+            y += lay.TEXT_HEIGHT
         if (self.SEPARATE_FOUNDATIONS):
             for i in range(4):
                 for j in range(decks):
@@ -143,6 +147,8 @@ class Canfield(Game):
         s.reserves.append(self.ReserveStack_Class(x, y, self))
         s.reserves[0].CARD_YOFFSET = yoffset
         x, y = lay.XM + 2 * lay.XS + lay.XM, lay.YM + lay.YS
+        if round_text:
+            y += lay.TEXT_HEIGHT
         if text:
             y += lay.TEXT_HEIGHT
         for i in range(rows):
@@ -348,6 +354,32 @@ class VariegatedCanfield(Canfield):
         pass
 
 
+# ************************************************************************
+# * Casino Canfield
+# ************************************************************************
+
+class CasinoCanfield(Canfield):
+    getGameScore = Game.getGameScoreCasino
+    getGameBalance = Game.getGameScoreCasino
+
+    def createGame(self, max_rounds=1, num_deal=1):
+        lay = Canfield.createGame(self, max_rounds=max_rounds,
+                                  num_deal=num_deal)
+        self.texts.score = MfxCanvasText(self.canvas,
+                                         8, self.height - 8, anchor="sw",
+                                         font=self.app.getFont("canvas_large"))
+        return lay
+
+    def updateText(self):
+        if self.preview > 1:
+            return
+        b1, b2 = self.app.stats.gameid_balance, 0
+        if self.shallUpdateBalance():
+            b2 = self.getGameBalance()
+        t = _("Balance $%d") % (b1 + b2)
+        self.texts.score.config(text=t)
+
+
 # ************************************************************************
 # * Eagle Wing
 # ************************************************************************
@@ -918,7 +950,8 @@ registerGame(GameInfo(103, AmericanToad, "American Toad",
 registerGame(GameInfo(102, VariegatedCanfield, "Variegated Canfield",
                       GI.GT_CANFIELD, 2, 2, GI.SL_BALANCED))
 registerGame(GameInfo(112, EagleWing, "Eagle Wing",
-                      GI.GT_CANFIELD, 1, 2, GI.SL_BALANCED))
+                      GI.GT_CANFIELD, 1, 2, GI.SL_BALANCED,
+                      altnames="Thirteen Down"))
 registerGame(GameInfo(315, Gate, "Gate",
                       GI.GT_CANFIELD, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(316, LittleGate, "Little Gate",
@@ -948,3 +981,6 @@ registerGame(GameInfo(642, Lafayette, "Lafayette",
                       GI.GT_CANFIELD, 1, -1, GI.SL_BALANCED))
 registerGame(GameInfo(789, Beehive, "Beehive",
                       GI.GT_CANFIELD, 1, -1, GI.SL_BALANCED))
+registerGame(GameInfo(835, CasinoCanfield, "Casino Canfield",
+                      GI.GT_CANFIELD | GI.GT_SCORE, 1, 0, GI.SL_BALANCED,
+                      altnames="Reno"))
