@@ -90,7 +90,7 @@ class FortyThieves(Game):
         # (piles up to 12 cards are playable without overlap
         #   in default window size)
         h = max(2*l.YS, l.YS+(playcards-1)*l.YOFFSET)
-        self.setSize(w1, l.YM + l.YS + h + l.YS + l.TEXT_HEIGHT)
+        self.setSize(w1, l.YM + l.YS + h + l.YS + (2 * l.TEXT_HEIGHT))
 
         # create stacks
         # foundations
@@ -111,16 +111,16 @@ class FortyThieves(Game):
             x = x + l.XS
         # talon, waste
         x = self.width - l.XS
-        y = self.height - l.YS
+        y = self.height - l.YS - l.TEXT_HEIGHT
         s.talon = WasteTalonStack(x, y, self,
                                   max_rounds=max_rounds, num_deal=num_deal)
-        l.createText(s.talon, "n")
+        l.createText(s.talon, "s")
         if max_rounds > 1:
-            l.createRoundText(s.talon, 'nnn')
+            l.createRoundText(s.talon, 'n')
         x -= l.XS
         s.waste = WasteStack(x, y, self)
         s.waste.CARD_XOFFSET = -l.XOFFSET
-        l.createText(s.waste, "n")
+        l.createText(s.waste, "s")
 
         # define stack-groups
         l.defaultStackGroups()
@@ -159,6 +159,7 @@ class FortyThieves(Game):
 # * Carre Napoleon
 # * Josephine
 # * Marie Rose
+# * Malmaison
 # * Big Courtyard
 # * San Juan Hill
 # * Famous Fifty
@@ -242,6 +243,13 @@ class MarieRose(Josephine):
         FortyThieves.createGame(self, rows=12, playcards=16, XCARDS=96)
 
 
+class Malmaison(MarieRose):
+    DEAL = (0, 8)
+
+    def createGame(self):
+        FortyThieves.createGame(self, rows=10, playcards=16, XCARDS=128)
+
+
 class BigCourtyard(Courtyard):
     def createGame(self):
         FortyThieves.createGame(self, rows=12, playcards=16, XCARDS=96)
@@ -288,6 +296,7 @@ class EightyThieves(FortyThieves):
 
 # ************************************************************************
 # * Deuces
+# * Pluto
 # ************************************************************************
 
 class Deuces(FortyThieves):
@@ -309,6 +318,18 @@ class Deuces(FortyThieves):
     shallHighlightMatch = Game._shallHighlightMatch_SSW
 
 
+class Pluto(Deuces):
+    def createGame(self):
+        FortyThieves.createGame(self, rows=12)
+
+    def _shuffleHook(self, cards):
+        return FortyThieves._shuffleHook(self, cards)
+
+    def startGame(self):
+        self.startDealSample()
+        FortyThieves.startGame(self)
+
+
 # ************************************************************************
 # * Corona
 # * Quadrangle
@@ -724,8 +745,8 @@ class Octagon(Game):
 
         l, s = Layout(self), self.s
 
-        w1 = l.XS+12*l.XOFFSET
-        w, h = l.XM+2*l.XS+2*w1, l.YM+4*l.YS
+        w1 = max(l.XS + 12 * l.XOFFSET, l.XM + 2 * l.XS + l.XS // 2)
+        w, h = l.XM + 2 * l.XS + 2 * w1, l.YM + 4 * l.YS
         self.setSize(w, h)
 
         for x, y in ((l.XM,                l.YM),
@@ -904,7 +925,9 @@ class Crossroads(Junction):
 
 
 # ************************************************************************
+# * Inverse Spark
 # * The Spark
+# * Single Spark
 # ************************************************************************
 
 class TheSpark_Talon(TalonStack):
@@ -929,20 +952,27 @@ class TheSpark_Talon(TalonStack):
         return num_cards
 
 
-class TheSpark(Game):
+# Version of The Spark with incorrect rules from 2.14 and earlier.
+# Renamed Kilowatt to differentiate from the correct version.
+class Kilowatt(Game):
     Hint_Class = CautiousDefaultHint
 
+    PER_ROW = 6
+    FOUNDATION_DIR = 1
+    ROW_DIR = -1
+
     def createGame(self):
 
         l, s = Layout(self), self.s
 
-        w, h = l.XM+8*l.XS, l.YM+4*l.YS
+        w, h = l.XM + (self.PER_ROW + 2) * l.XS, l.YM + 4 * l.YS
         self.setSize(w, h)
 
         x, y = l.XM, l.YM
-        for i in range(8):
+        for i in range(self.gameinfo.decks * 4):
             s.foundations.append(SS_FoundationStack(x, y, self,
-                                 suit=i//2, base_rank=KING, mod=13))
+                                 suit=i//self.gameinfo.decks, base_rank=KING,
+                                 mod=13, dir=self.FOUNDATION_DIR))
             x += l.XS
         x, y = l.XM, l.YM+l.YS
         s.talon = TheSpark_Talon(x, y, self, max_rounds=1, num_deal=3)
@@ -956,8 +986,9 @@ class TheSpark(Game):
         y = l.YM+l.YS*3//2
         for i in range(2):
             x = l.XM+2*l.XS
-            for j in range(6):
-                stack = SS_RowStack(x, y, self, max_move=1)
+            for j in range(self.PER_ROW):
+                stack = SS_RowStack(x, y, self, max_move=1,
+                                    dir=self.ROW_DIR)
                 stack.CARD_XOFFSET, stack.CARD_YOFFSET = 0, 0
                 s.rows.append(stack)
                 x += l.XS
@@ -966,7 +997,7 @@ class TheSpark(Game):
         l.defaultStackGroups()
 
     def _shuffleHook(self, cards):
-        # move Aces to top of the Talon (i.e. first cards to be dealt)
+        # move Kings to top of the Talon (i.e. first cards to be dealt)
         return self._shuffleHookMoveToTop(cards,
                                           lambda c: (c.rank == KING, c.suit))
 
@@ -977,6 +1008,21 @@ class TheSpark(Game):
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
 
+class TheSpark(Kilowatt):
+    FOUNDATION_DIR = -1
+    ROW_DIR = 1
+
+    def _shuffleHook(self, cards):
+        return Game._shuffleHook(self, cards)
+
+    def startGame(self):
+        self._startAndDealRowAndCards()
+
+
+class SingleSpark(TheSpark):
+    PER_ROW = 4
+
+
 # ************************************************************************
 # * Double Gold Mine
 # ************************************************************************
@@ -1378,9 +1424,9 @@ registerGame(GameInfo(529, SanJuanHill, "San Juan Hill",
 registerGame(GameInfo(540, Waterloo, "Waterloo",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(556, Junction, "Junction",
-                      GI.GT_FORTY_THIEVES, 4, 0, GI.SL_MOSTLY_SKILL,
-                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
-registerGame(GameInfo(564, TheSpark, "The Spark",
+                      GI.GT_FORTY_THIEVES | GI.GT_STRIPPED, 4, 0,
+                      GI.SL_MOSTLY_SKILL, ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
+registerGame(GameInfo(564, Kilowatt, "Kilowatt",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(573, DoubleGoldMine, "Double Gold Mine",
                       GI.GT_NUMERICA | GI.GT_ORIGINAL, 2, 0,
@@ -1420,3 +1466,13 @@ registerGame(GameInfo(815, Following, "Following",
                       GI.GT_FORTY_THIEVES, 1, 1, GI.SL_BALANCED))
 registerGame(GameInfo(818, TripleRail, "Triple Rail",
                       GI.GT_FORTY_THIEVES, 3, 0, GI.SL_BALANCED))
+registerGame(GameInfo(837, SingleSpark, "Single Spark",
+                      GI.GT_FORTY_THIEVES, 1, 0, GI.SL_MOSTLY_LUCK,
+                      altnames=("Simple Spark")))
+registerGame(GameInfo(838, TheSpark, "The Spark",
+                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_LUCK))
+registerGame(GameInfo(847, Pluto, "Pluto",
+                      GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL,
+                      altnames=("Square")))
+registerGame(GameInfo(848, Malmaison, "Malmaison",
+                      GI.GT_FORTY_THIEVES, 4, 0, GI.SL_MOSTLY_SKILL))
