@@ -743,8 +743,8 @@ class Waterfall(Game):
     def createGame(self):
         rows = 8
         layout, s = Layout(self), self.s
-        self.setSize(
-            layout.XM+rows*layout.XS, layout.YM+2*layout.YS+20*layout.YOFFSET)
+        self.setSize(layout.XM + rows * layout.XS,
+                     layout.YM + 2 * layout.YS + 30 * layout.YOFFSET)
 
         x, y = layout.XM, layout.YM
         for i in range(rows):
@@ -1115,8 +1115,9 @@ class NapoleonTakesMoscow(Game, FirTree_GameMethods):
     def createGame(self):
 
         layout, s = Layout(self), self.s
-        self.setSize(
-            layout.XM+10*layout.XS, layout.YM+3*layout.YS+15*layout.YOFFSET)
+        self.setSize(layout.XM + 10 * layout.XS,
+                     layout.YM + 3 * layout.YS + 15 * layout.YOFFSET +
+                     layout.TEXT_HEIGHT)
 
         x, y = layout.XM+layout.XS, layout.YM
         for i in range(8):
@@ -1133,13 +1134,13 @@ class NapoleonTakesMoscow(Game, FirTree_GameMethods):
         x, y = layout.XM+4*layout.XS, layout.YM+layout.YS
         s.reserves += self._createFirTree(layout, x, y)
 
-        x, y = layout.XM, self.height-layout.YS
+        x, y = layout.XM, self.height - layout.YS - layout.TEXT_HEIGHT
         s.talon = WasteTalonStack(x, y, self, max_rounds=3)
-        layout.createText(s.talon, 'n')
-        layout.createRoundText(s.talon, 'nnn')
+        layout.createText(s.talon, 's')
+        layout.createRoundText(s.talon, 'n')
         x += layout.XS
         s.waste = WasteStack(x, y, self)
-        layout.createText(s.waste, 'n')
+        layout.createText(s.waste, 's')
 
         # define stack-groups
         layout.defaultStackGroups()
@@ -1304,9 +1305,9 @@ registerGame(GameInfo(728, ThirtyTwoCards, "Thirty Two Cards",
 registerGame(GameInfo(731, ThreeFirTrees, "Three Fir-trees",
                       GI.GT_GOLF, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(733, NapoleonTakesMoscow, "Napoleon Takes Moscow",
-                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_BALANCED))
+                      GI.GT_NAPOLEON, 2, 2, GI.SL_BALANCED))
 registerGame(GameInfo(734, NapoleonLeavesMoscow, "Napoleon Leaves Moscow",
-                      GI.GT_2DECK_TYPE, 2, 2, GI.SL_BALANCED,
+                      GI.GT_NAPOLEON, 2, 2, GI.SL_BALANCED,
                       altnames=("Napoleon at Friedland",)))
 registerGame(GameInfo(749, Flake, "Flake",
                       GI.GT_GOLF | GI.GT_OPEN | GI.GT_ORIGINAL,
@@ -1328,5 +1329,5 @@ registerGame(GameInfo(783, Uintah, "Uintah",
                       GI.GT_GOLF, 1, UNLIMITED_REDEALS,
                       GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(812, Sticko, "Sticko",
-                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED,
+                      GI.GT_1DECK_TYPE | GI.GT_STRIPPED, 1, 0, GI.SL_BALANCED,
                       ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
