@@ -560,6 +560,7 @@ class FlowerGarden(Stonewall):
 # * King Albert
 # * Raglan
 # * Brigade
+# * Relaxed Raglan
 # * Queen Victoria
 # ************************************************************************
 
@@ -621,6 +622,10 @@ class Brigade(Raglan):
     shallHighlightMatch = Game._shallHighlightMatch_RK
 
 
+class RelaxedRaglan(Raglan):
+    RowStack_Class = AC_RowStack
+
+
 class QueenVictoria(KingAlbert):
     RowStack_Class = AC_RowStack
 
@@ -740,8 +745,9 @@ class Senate(Jane):
         playcards = 10
 
         lay, s = Layout(self), self.s
-        self.setSize(lay.XM+(rows+7)*lay.XS,
-                     lay.YM+2*(lay.YS+playcards*lay.YOFFSET))
+        self.setSize(lay.XM + (rows + 7) * lay.XS,
+                     max(lay.YM + 2 * (lay.YS + playcards * lay.YOFFSET),
+                         lay.YS * 5))
 
         x, y = lay.XM, lay.YM
         for i in range(rows):
@@ -907,7 +913,7 @@ class Q_C_(Klondike):
 
     def createGame(self):
         lay = Klondike.createGame(self, rows=6, max_rounds=2)
-        lay.createRoundText(self.s.talon, 'sss')
+        lay.createRoundText(self.s.talon, 'n')
 
     def startGame(self):
         self._startDealNumRows(3)
@@ -1390,9 +1396,70 @@ class EightSages(Klondike):
         self.s.talon.dealCards()
 
 
+# ************************************************************************
+# * Guardian
+# ************************************************************************
+
+class Guardian_RowStack(AC_RowStack):
+    STEP = (3, 3, 3, 4, 4, 4, 4)
+
+    def basicIsBlocked(self):
+        r, step = self.game.s.rows, self.STEP
+        i, n, mylen = self.id, 1, len(step)
+        while i < mylen:
+            i = i + step[i]
+            n = n + 1
+            for j in range(i, i + n):
+                if r[j].cards:
+                    return True
+        return False
+
+    def acceptsCards(self, from_stack, cards):
+        if len(self.cards) == 0 and self.id > 2:
+            return False
+        return AC_RowStack.acceptsCards(self, from_stack, cards)
+
+
+class Guardian(Game):
+
+    def createGame(self):
+        lay, s = Layout(self), self.s
+        self.setSize((7 * lay.XS) + lay.XM,
+                     (2.5 * lay.YS) + (13 * lay.YOFFSET) + lay.YM)
+
+        # create stacks
+        for i in range(3):
+            x = lay.XM + (4 - i) * lay.XS // 2
+            y = lay.YM + lay.TEXT_HEIGHT + lay.YS + i * lay.YS // 4
+            for j in range(i + 3):
+                s.rows.append(Guardian_RowStack(x, y, self))
+                x = x + lay.XS
+
+        x, y = lay.XM, lay.YM
+        s.talon = WasteTalonStack(x, y, self,
+                                  max_rounds=-1, num_deal=3)
+        lay.createText(s.talon, "s")
+        x += lay.XS
+        s.waste = WasteStack(x, y, self)
+        lay.createText(s.waste, "s")
+        x += lay.XS
+        for i in range(4):
+            x += lay.XS
+            s.foundations.append(SS_FoundationStack(x, y, self, i,
+                                                    mod=13, max_move=0))
+        lay.defaultStackGroups()
+
+    def startGame(self):
+        self.startDealSample()
+        self.s.talon.dealRow(rows=self.s.rows[:7], flip=0)
+        self.s.talon.dealRow(rows=self.s.rows[7:])
+        self.s.talon.dealCards()  # deal first card to WasteStack
+
+
 # register the game
 registerGame(GameInfo(2, Klondike, "Klondike",
-                      GI.GT_KLONDIKE, 1, -1, GI.SL_BALANCED))
+                      GI.GT_KLONDIKE, 1, -1, GI.SL_BALANCED,
+                      altnames=("Classic Solitaire", "American Patience")))
 registerGame(GameInfo(61, CasinoKlondike, "Casino Klondike",
                       GI.GT_KLONDIKE | GI.GT_SCORE, 1, 2, GI.SL_BALANCED))
 registerGame(GameInfo(129, VegasKlondike, "Vegas Klondike",
@@ -1475,7 +1542,7 @@ registerGame(GameInfo(390, Arizona, "Arizona",
 registerGame(GameInfo(407, AuntMary, "Aunt Mary",
                       GI.GT_KLONDIKE, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(420, DoubleDot, "Double Dot",
-                      GI.GT_KLONDIKE, 1, 0, GI.SL_BALANCED))
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_BALANCED))
 registerGame(GameInfo(434, SevenDevils, "Seven Devils",
                       GI.GT_RAGLAN, 2, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(452, DoubleEasthaven, "Double Easthaven",
@@ -1538,3 +1605,8 @@ registerGame(GameInfo(726, EightSages, "Eight Sages",
                       GI.GT_KLONDIKE, 2, 1, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(821, Trigon, "Trigon",
                       GI.GT_KLONDIKE, 1, -1, GI.SL_BALANCED))
+registerGame(GameInfo(849, RelaxedRaglan, "Relaxed Raglan",
+                      GI.GT_RAGLAN | GI.GT_RELAXED | GI.GT_OPEN, 1, 0,
+                      GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(852, Guardian, "Guardian",
+                      GI.GT_KLONDIKE, 1, -1, GI.SL_BALANCED))
