@@ -21,32 +21,23 @@
 #
 # ---------------------------------------------------------------------------
 
-# Imports
-from gettext import ungettext
-from six.moves import range
-
-from pysollib.settings import TOOLKIT
-
-# PySol imports
-from pysollib.mygettext import _
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.mfxutil import kwdefault
-from pysollib.layout import Layout
+from pysollib.gamedb import GI, GameInfo, registerGame
+from pysollib.games.mahjongg.mahjongg import AbstractMahjonggGame, \
+        Mahjongg_RowStack, \
+        comp_cardset
 from pysollib.hint import AbstractHint
-from pysollib.pysoltk import MfxCanvasText, MfxCanvasLine
-
-from pysollib.games.mahjongg.mahjongg import Mahjongg_RowStack, \
-        AbstractMahjonggGame, comp_cardset
-
-from pysollib.util import ANY_SUIT
-
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
+from pysollib.mygettext import _
+from pysollib.mygettext import ungettext
+from pysollib.pysoltk import MfxCanvasLine, MfxCanvasText
+from pysollib.settings import TOOLKIT
 from pysollib.stack import \
         AbstractFoundationStack, \
         InitialDealTalonStack
+from pysollib.util import ANY_SUIT
 
-# ************************************************************************
-# *
-# ************************************************************************
+from six.moves import range
 
 
 class Shisen_Hint(AbstractHint):
@@ -259,7 +250,8 @@ class Shisen_RowStack(Mahjongg_RowStack):
         cs = game.app.cardset
         path = self.acceptsCards(other_stack, [other_stack.cards[-1]])
         # print path
-        x0, y0 = game.XMARGIN, game.YMARGIN
+        x0, y0 = (game.XMARGIN + game.center_offset[0],
+                  game.YMARGIN + game.center_offset[1])
         cardw, cardh = images.CARDW, images.CARDH
         if cs.version >= 6:
             cardw -= cs.SHADOW_XOFFSET
@@ -318,7 +310,7 @@ class AbstractShisenGame(AbstractMahjonggGame):
         l, s = Layout(self), self.s
         # dx, dy = 3, -3
 
-        cs = self.app.cardset
+        cs = self.app.images.cs
         if cs.version >= 6:
             dx = l.XOFFSET
             dy = -l.YOFFSET
@@ -331,6 +323,10 @@ class AbstractShisenGame(AbstractMahjonggGame):
             d_x = 0
             d_y = 0
             self._delta_x, self._delta_y = 0, 0
+        # TODO - This should be moved to subsample logic in the future.
+        if self.preview > 1:
+            d_x /= 2
+            d_y /= 2
 
         font = self.app.getFont("canvas_default")
 
