@@ -336,6 +336,30 @@ class SimplePairs(MonteCarlo):
         return 0 <= stack1.id <= 15 and 0 <= stack2.id <= 15
 
 
+# ************************************************************************
+# * Block Ten
+# ************************************************************************
+
+class BlockTen_RowStack(MonteCarlo_RowStack):
+    def acceptsCards(self, from_stack, cards):
+        if not OpenStack.acceptsCards(self, from_stack, cards):
+            return False
+        # check the rank
+        if self.cards[-1].rank + cards[0].rank + 2 == 10:
+            return True
+        if self.cards[-1].rank > 9 and self.cards[-1].rank == cards[0].rank:
+            return True
+
+        return False
+
+
+class BlockTen(SimplePairs):
+    RowStack_Class = BlockTen_RowStack
+
+    def isGameWon(self):
+        return len(self.s.foundations[0].cards) == 48
+
+
 # ************************************************************************
 # * Neighbour
 # ************************************************************************
@@ -952,7 +976,9 @@ registerGame(GameInfo(92, Neighbour, "Neighbour",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(96, Fourteen, "Fourteen",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
-                      GI.SL_MOSTLY_LUCK, altnames=("Fourteen Out",)))
+                      GI.SL_MOSTLY_LUCK, altnames=("Fourteen Out",
+                                                   "Fourteen Puzzle",
+                                                   "Take Fourteen")))
 registerGame(GameInfo(235, Nestor, "Nestor",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
                       GI.SL_MOSTLY_LUCK))
@@ -960,11 +986,12 @@ registerGame(GameInfo(152, DerLetzteMonarch, "The Last Monarch",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Der letzte Monarch",)))
 registerGame(GameInfo(328, TheWish, "The Wish",
-                      GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
-                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
+                      GI.GT_PAIRING_TYPE | GI.GT_STRIPPED, 1, 0,
+                      GI.SL_MOSTLY_LUCK, ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
 registerGame(GameInfo(329, TheWishOpen, "The Wish (open)",
-                      GI.GT_PAIRING_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0,
-                      GI.SL_MOSTLY_SKILL, ranks=(0, 6, 7, 8, 9, 10, 11, 12),
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL |
+                      GI.GT_STRIPPED, 1, 0, GI.SL_MOSTLY_SKILL,
+                      ranks=(0, 6, 7, 8, 9, 10, 11, 12),
                       rules_filename="thewish.html"))
 registerGame(GameInfo(368, Vertical, "Vertical",
                       GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0,
@@ -981,3 +1008,5 @@ registerGame(GameInfo(801, DoubleNestor, "Double Nestor",
                       GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(810, Quatorze, "Quatorze",
                       GI.GT_PAIRING_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
+registerGame(GameInfo(829, BlockTen, "Block Ten",
+                      GI.GT_PAIRING_TYPE, 1, 0, GI.SL_LUCK))
