@@ -397,7 +397,8 @@ registerGame(GameInfo(41, PileOn, "PileOn",
                       GI.GT_1DECK_TYPE | GI.GT_OPEN, 1, 0, GI.SL_MOSTLY_SKILL,
                       altnames=("Fifteen Puzzle", "Fan Fifteen", )))
 registerGame(GameInfo(289, SmallPileOn, "Small PileOn",
-                      GI.GT_1DECK_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL, 1, 0,
+                      GI.GT_1DECK_TYPE | GI.GT_OPEN | GI.GT_ORIGINAL |
+                      GI.GT_STRIPPED, 1, 0,
                       GI.SL_MOSTLY_SKILL,
                       ranks=(0, 5, 6, 7, 8, 9, 10, 11, 12),
                       rules_filename="pileon.html"))
