@@ -233,7 +233,8 @@ class Pyramid(Game):
                 n += 1
         return rows
 
-    def createGame(self, pyramid_len=7, reserves=0, waste=True, texts=True):
+    def createGame(self, pyramid_len=7, reserves=0, waste=True,
+                   texts=True, playcards=2):
         # create layout
         layout, s = Layout(self), self.s
 
@@ -243,7 +244,7 @@ class Pyramid(Game):
         h = layout.YM + layout.YS + \
             (pyramid_len-1)*layout.YS//self.PYRAMID_Y_FACTOR
         if reserves:
-            h += layout.YS+2*layout.YOFFSET
+            h += layout.YS + playcards * layout.YOFFSET
         self.setSize(w, h)
 
         # create stacks
@@ -334,6 +335,53 @@ class Giza(Pyramid):
         self.s.talon.dealRow(frames=4)
 
 
+# ************************************************************************
+# * Pyramid Dozen
+# ************************************************************************
+
+class PyramidDozen_StackMethods():
+    def acceptsCards(self, from_stack, cards):
+        if self.basicIsBlocked():
+            return False
+        if from_stack is self or not self.cards or len(cards) != 1:
+            return False
+        c = self.cards[-1]
+        return c.face_up and cards[0].face_up and \
+            (cards[0].rank + c.rank == 10 or cards[0].rank + c.rank == 23)
+
+    def _dropKingClickHandler(self, event):
+        return 0
+
+
+class PyramidDozen_RowStack(PyramidDozen_StackMethods, Pyramid_RowStack):
+    pass
+
+
+class PyramidDozen_Reserve(PyramidDozen_StackMethods, Giza_Reserve):
+    pass
+
+
+class PyramidDozen_Foundation(AbstractFoundationStack):
+    def acceptsCards(self, from_stack, cards):
+        return False
+
+
+class PyramidDozen(Giza):
+    RowStack_Class = PyramidDozen_RowStack
+    Reserve_Class = StackWrapper(PyramidDozen_Reserve, max_accept=1)
+    Foundation_Class = PyramidDozen_Foundation
+
+    def createGame(self):
+        Pyramid.createGame(self, reserves=6, waste=False, texts=False,
+                           playcards=3)
+
+    def startGame(self):
+        for i in range(4):
+            self.s.talon.dealRow(rows=self.s.reserves, frames=0)
+        self.startDealSample()
+        self.s.talon.dealRow(frames=4)
+
+
 # ************************************************************************
 # * Thirteen
 # * FIXME: UNFINISHED
@@ -486,9 +534,13 @@ class Elevens(Pyramid):
 
         layout, s = Layout(self), self.s
 
+        rp = 0
+        if reserves > 0:
+            rp = 1.5
+
         self.setSize(
-            layout.XM+(cols+2)*layout.XS,
-            layout.YM+(rows+1.5)*layout.YS)
+            layout.XM + (cols + 2) * layout.XS,
+            layout.YM + (rows + rp) * layout.YS)
 
         x, y = self.width-layout.XS, layout.YM
         s.talon = TalonStack(x, y, self)
@@ -534,7 +586,8 @@ class Elevens(Pyramid):
         for s in self.s.reserves:
             if s.cards:
                 reserves_ncards += 1
-        if reserves_ncards == len(self.s.reserves):
+        if (reserves_ncards == len(self.s.reserves) and
+                len(self.s.reserves) > 0):
             if not self.demo:
                 self.playSample("droppair", priority=200)
             for s in self.s.reserves:
@@ -661,6 +714,35 @@ class Fifteens(Elevens):
         self.leaveState(old_state)
 
 
+# ************************************************************************
+# * Neptune
+# ************************************************************************
+
+class Neptune_RowStack(Elevens_RowStack):
+
+    def acceptsCards(self, from_stack, cards):
+        if from_stack is self or not self.cards or len(cards) != 1:
+            return False
+        c = self.cards[-1]
+        return (c.face_up and cards[0].face_up and
+                (cards[0].rank == c.rank - 1 or cards[0].rank == c.rank + 1))
+
+    def moveMove(self, ncards, to_stack, frames=-1, shadow=-1):
+        if to_stack in self.game.s.rows:
+            self._dropPairMove(ncards, to_stack, frames=-1, shadow=shadow)
+        self.fillStack()
+
+
+class Neptune(Elevens):
+    RowStack_Class = Neptune_RowStack
+
+    def createGame(self):
+        Elevens.createGame(self, rows=4, cols=2, reserves=0)
+
+    def isGameWon(self):
+        return len(self.s.talon.cards) == 0
+
+
 # ************************************************************************
 # * Triple Alliance
 # ************************************************************************
@@ -1422,3 +1504,7 @@ registerGame(GameInfo(796, Exit, "Exit",
 registerGame(GameInfo(802, TripleAlliance2Decks, "Triple Alliance (2 decks)",
                       GI.GT_2DECK_TYPE | GI.GT_OPEN, 2, 0,
                       GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(846, PyramidDozen, "Pyramid Dozen",
+                      GI.GT_PAIRING_TYPE | GI.GT_OPEN, 1, 0, GI.SL_BALANCED))
+registerGame(GameInfo(854, Neptune, "Neptune",
+                      GI.GT_PAIRING_TYPE, 1, 0, GI.SL_BALANCED))
