@@ -42,6 +42,7 @@ from pysollib.stack import \
         RK_RowStack, \
         ReserveStack, \
         SS_FoundationStack, \
+        SS_RowStack, \
         Spider_AC_Foundation, \
         Spider_SS_Foundation, \
         Spider_SS_RowStack, \
@@ -1411,6 +1412,69 @@ class AutumnLeaves(Game):
         return True
 
 
+# ************************************************************************
+# * Scorpion Towers
+# ************************************************************************
+
+class ScorpionTowers_RowStack(SS_RowStack):
+    def acceptsCards(self, from_stack, cards):
+        if not self.cards:
+            basekings = 0
+            for s in self.game.s.rows:
+                if s.cards and s.cards[0].rank == KING:
+                    basekings += 1
+            if basekings >= 4:
+                return 1
+            else:
+                return cards[0].rank == KING
+        return SS_RowStack.acceptsCards(self, from_stack, cards)
+
+
+class ScorpionTowers(Game):
+    Layout_Method = staticmethod(Layout.freeCellLayout)
+    Talon_Class = InitialDealTalonStack
+    RowStack_Class = ScorpionTowers_RowStack
+    Hint_Class = Spider_Hint
+
+    def createGame(self, **layout):
+        # create layout
+        l, s = Layout(self), self.s
+
+        # set window
+        # (piles up to 20 cards are playable in default window size)
+        h = max(3 * l.YS, 20 * l.YOFFSET)
+        self.setSize(l.XM + 10 * l.XS, l.YM + l.YS + h)
+
+        # create stacks
+        x, y = l.XM, l.YM
+        for i in range(4):
+            s.reserves.append(ReserveStack(x + (i + 3) * l.XS, y, self))
+        x, y = l.XM, l.YM + l.YS
+        for i in range(10):
+            s.rows.append(self.RowStack_Class(x, y, self))
+            x = x + l.XS
+        s.talon = self.Talon_Class(l.XM, self.height - l.YS, self)
+
+        # define stack-groups
+        self.sg.openstacks = s.foundations + s.rows + s.reserves
+        self.sg.talonstacks = [s.talon]
+        self.sg.dropstacks = s.rows + s.reserves
+        self.sg.reservestacks = s.reserves
+
+    def startGame(self):
+        for i in range(4):
+            self.s.talon.dealRow(flip=1, frames=0)
+        self._startAndDealRow()
+        self.s.talon.dealRow(rows=[self.s.reserves[1], self.s.reserves[2]])
+
+    def isGameWon(self):
+        for s in self.s.rows:
+            if s.cards:
+                if len(s.cards) != 13 or not isSameSuitSequence(s.cards):
+                    return False
+        return True
+
+
 # register the game
 registerGame(GameInfo(10, RelaxedSpider, "Relaxed Spider",
                       GI.GT_SPIDER | GI.GT_RELAXED, 2, 0, GI.SL_MOSTLY_SKILL))
@@ -1490,9 +1554,8 @@ registerGame(GameInfo(446, BigSpider2Suits, "Big Spider (2 suits)",
                       suits=(0, 0, 2, 2),
                       rules_filename="bigspider.html"))
 registerGame(GameInfo(449, Spider3x3, "Spider 3x3",
-                      GI.GT_SPIDER | GI.GT_ORIGINAL, 3, 0, GI.SL_MOSTLY_SKILL,
-                      suits=(0, 1, 2),
-                      rules_filename="bigspider.html"))
+                      GI.GT_SPIDER | GI.GT_ORIGINAL | GI.GT_STRIPPED,
+                      3, 0, GI.SL_MOSTLY_SKILL, suits=(0, 1, 2)))
 registerGame(GameInfo(454, Spider4Decks, "Spider (4 decks)",
                       GI.GT_SPIDER, 4, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(455, GroundsForADivorce4Decks, "Very Big Divorce",
@@ -1523,7 +1586,7 @@ registerGame(GameInfo(570, LongTail, "Long Tail",
 registerGame(GameInfo(571, ShortTail, "Short Tail",
                       GI.GT_SPIDER | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(670, ChineseSpider, "Chinese Spider",
-                      GI.GT_SPIDER, 4, 0, GI.SL_MOSTLY_SKILL,
+                      GI.GT_SPIDER | GI.GT_STRIPPED, 4, 0, GI.SL_MOSTLY_SKILL,
                       suits=(0, 1, 2),))
 registerGame(GameInfo(671, Incompatibility, "Incompatibility",
                       GI.GT_SPIDER, 2, 0, GI.SL_MOSTLY_SKILL))
@@ -1542,3 +1605,5 @@ registerGame(GameInfo(711, TheJollyRoger, "The Jolly Roger",
                       GI.GT_SPIDER | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(788, AutumnLeaves, "Autumn Leaves",
                       GI.GT_SPIDER, 1, 0, GI.SL_MOSTLY_SKILL))
+registerGame(GameInfo(825, ScorpionTowers, "Scorpion Towers",
+                      GI.GT_SPIDER | GI.GT_OPEN, 1, 0, GI.SL_SKILL))
