@@ -21,28 +21,18 @@
 #
 # ---------------------------------------------------------------------------##
 
-# Imports
-
-# Ultrasol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.mfxutil import kwdefault
-from pysollib.layout import Layout
-
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.games.special.tarock import AbstractTarockGame, Grasshopper
 from pysollib.games.threepeaks import ThreePeaksNoScore
-
-from pysollib.util import ANY_RANK, NO_RANK, UNLIMITED_ACCEPTS, UNLIMITED_MOVES
-
+from pysollib.layout import Layout
+from pysollib.mfxutil import kwdefault
 from pysollib.stack import \
         InitialDealTalonStack, \
+        OpenStack, \
         ReserveStack, \
         SS_FoundationStack, \
-        StackWrapper, \
-        OpenStack
-
-# ************************************************************************
-# *
-# ************************************************************************
+        StackWrapper
+from pysollib.util import ANY_RANK, NO_RANK, UNLIMITED_ACCEPTS, UNLIMITED_MOVES
 
 
 class Tarock_OpenStack(OpenStack):
@@ -292,7 +282,10 @@ def r(id, gameclass, name, game_type, decks, redeals, skill_level):
 r(13163, Cockroach, 'Cockroach', GI.GT_TAROCK, 1, 0, GI.SL_MOSTLY_SKILL)
 r(13164, DoubleCockroach, 'Double Cockroach', GI.GT_TAROCK, 2, 0,
   GI.SL_MOSTLY_SKILL)
-r(13165, Corkscrew, 'Corkscrew', GI.GT_TAROCK, 2, 0, GI.SL_MOSTLY_SKILL)
-r(13166, Serpent, 'Serpent', GI.GT_TAROCK, 2, 0, GI.SL_MOSTLY_SKILL)
-r(13167, Rambling, 'Rambling', GI.GT_TAROCK, 2, 0, GI.SL_MOSTLY_SKILL)
+r(13165, Corkscrew, 'Corkscrew', GI.GT_TAROCK | GI.GT_OPEN, 2, 0,
+  GI.SL_MOSTLY_SKILL)
+r(13166, Serpent, 'Serpent', GI.GT_TAROCK | GI.GT_OPEN, 2, 0,
+  GI.SL_MOSTLY_SKILL)
+r(13167, Rambling, 'Rambling', GI.GT_TAROCK | GI.GT_OPEN, 2, 0,
+  GI.SL_MOSTLY_SKILL)
 r(22232, LeGrandeTeton, 'Le Grande Teton', GI.GT_TAROCK, 1, 0, GI.SL_BALANCED)
