@@ -428,18 +428,16 @@ class Simplicity(Game):
 
 # register the game
 registerGame(GameInfo(30, Windmill, "Windmill",
-                      GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_LUCK))
+                      GI.GT_2DECK_TYPE, 2, 0, GI.SL_MOSTLY_LUCK,
+                      altnames=('Propeller',)))
 registerGame(GameInfo(277, NapoleonsTomb, "Napoleon's Tomb",
                       GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(417, Corners, "Corners",
-                      GI.GT_1DECK_TYPE, 1, 2, GI.SL_MOSTLY_LUCK,
-                      rules_filename='fourseasons.html'))
+                      GI.GT_1DECK_TYPE, 1, 2, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(437, Simplicity, "Simplicity",
-                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
-                      rules_filename='fourseasons.html'))
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(483, Czarina, "Czarina",
-                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
-                      rules_filename='fourseasons.html'))
+                      GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(484, FourSeasons, "Four Seasons",
                       GI.GT_1DECK_TYPE, 1, 0, GI.SL_MOSTLY_LUCK,
                       altnames=('Corner Card', 'Vanishing Cross')))
