@@ -25,7 +25,8 @@
 import os
 
 from pysollib.mfxutil import Image, ImageTk, USE_PIL, print_err
-from pysollib.pysoltk import copyImage, createBottom, createImage, loadImage
+from pysollib.pysoltk import copyImage, createBottom, createImage,\
+        createImagePIL, loadImage
 from pysollib.pysoltk import shadowImage
 from pysollib.resource import CSI
 from pysollib.settings import TOOLKIT
@@ -73,6 +74,8 @@ class Images:
         self._highlight_index = 0       #
         self._highlighted_images = {}   # key: (suit, rank)
 
+        self.cardset_bottoms = False
+
     def destruct(self):
         pass
 
@@ -109,14 +112,12 @@ class Images:
             imagedir = self.d.findDir(cs_type, d)
         except Exception:
             pass
-        if (not USE_PIL and TOOLKIT != 'kivy') or imagedir is None:
+        if ((not USE_PIL and TOOLKIT != 'kivy') or self.cardset_bottoms
+                or imagedir is None):
             # load image
             img = self.__loadCard(filename+self.cs.ext, check_w, check_h)
-            if USE_PIL and img is not None:
-                # we have no bottom images
-                # (data/images/cards/bottoms/<cs_type>)
-                img = img.resize(self._xfactor, self._yfactor)
             return img
+
         # create image
         d = os.path.join('images', 'cards', 'bottoms', cs_type)
         try:
@@ -136,7 +137,8 @@ class Images:
         cw, ch = self.getSize()
         # back
         if not self._back:
-            im = createImage(cw, ch, fill="#a0a0a0", outline="#000000")
+            im = self.createMissingImage(cw, ch, fill="#a0a0a0",
+                                         outline="#000000")
             name = ""
             self.__addBack(im, name)
             self.cs.backnames = tuple(self.cs.backnames) + (name,)
@@ -145,21 +147,32 @@ class Images:
         neg_bottom = None
         while len(self._bottom_positive) < max(7, self.cs.nbottoms):
             if bottom is None:
-                bottom = createImage(cw, ch, fill=None, outline="#000000")
+                bottom = self.createMissingImage(cw, ch, fill=None,
+                                                 outline="#000000")
             self._bottom_positive.append(bottom)
         while len(self._bottom_negative) < max(7, self.cs.nbottoms):
             if neg_bottom is None:
-                neg_bottom = createImage(cw, ch, fill=None, outline="#ffffff")
+                neg_bottom = self.createMissingImage(cw, ch, fill=None,
+                                                     outline="#ffffff")
             self._bottom_negative.append(neg_bottom)
         while len(self._letter_positive) < 4:
             if bottom is None:
-                bottom = createImage(cw, ch, fill=None, outline="#000000")
+                bottom = self.createMissingImage(cw, ch, fill=None,
+                                                 outline="#000000")
             self._letter_positive.append(bottom)
         while len(self._letter_negative) < 4:
             if neg_bottom is None:
-                neg_bottom = createImage(cw, ch, fill=None, outline="#ffffff")
+                neg_bottom = self.createMissingImage(cw, ch, fill=None,
+                                                     outline="#ffffff")
             self._letter_negative.append(neg_bottom)
-        self._blank_bottom = createImage(cw, ch, fill=None, outline=None)
+        self._blank_bottom = self.createMissingImage(cw, ch, fill=None,
+                                                     outline=None)
+
+    def createMissingImage(self, width, height, fill, outline=None):
+        if USE_PIL:
+            return createImagePIL(width, height, fill=fill, outline=outline)
+        else:
+            return createImage(width, height, fill=fill, outline=outline)
 
     def load(self, app, progress=None):
         ext = self.cs.ext[1:]
@@ -188,6 +201,7 @@ class Images:
                                   cs_dir=self.cs.dir, fname=name))
         if progress:
             progress.update(step=1)
+
         # load bottoms
         for i in range(self.cs.nbottoms):
             name = "bottom%02d" % (i + 1)
@@ -206,16 +220,19 @@ class Images:
         # load letters
         for rank in range(self.cs.nletters):
             name = "l%02d" % (rank + 1)
-            self._letter_positive.append(
-                self.__loadBottom(name, color='black'))
+            bottom = self.__loadBottom(name, color='black')
+            if bottom is not None:
+                self._letter_positive.append(bottom)
             if progress:
                 progress.update(step=pstep)
             # load negative letters
             name = "l%02d-n" % (rank + 1)
-            self._letter_negative.append(
-                self.__loadBottom(name, color='white'))
+            bottom = self.__loadBottom(name, color='white')
+            if bottom is not None:
+                self._letter_negative.append(bottom)
             if progress:
                 progress.update(step=pstep)
+
         # shadow
         if not USE_PIL:
             for i in range(self.cs.nshadows):
@@ -431,29 +448,33 @@ class Images:
         # back
         for b in self._back:
             b.image = b.image.resize(xf, yf)
+
         # stack bottom image
-        neg = self._bottom is self._bottom_negative
-        self._bottom_negative = []
-        self._bottom_positive = []
-        for i in range(self.cs.nbottoms):
-            name = "bottom%02d" % (i + 1)
-            bottom = self.__loadBottom(name, color='black')
-            if bottom is not None:
-                self._bottom_positive.append(bottom)
-            name = "bottom%02d-n" % (i + 1)
-            bottom = self.__loadBottom(name, color='white')
-            if bottom is not None:
-                self._bottom_negative.append(bottom)
+        neg = self._bottom is self._bottom_negative  # dont know
+
+        bottom_negative = []
+        bottom_positive = []
+        for c in self._bottom_negative:
+            c = c.resize(xf, yf)
+            bottom_negative.append(c)
+        self._bottom_negative = bottom_negative
+        for c in self._bottom_positive:
+            c = c.resize(xf, yf)
+            bottom_positive.append(c)
+        self._bottom_positive = bottom_positive
+
         # letters
-        self._letter_positive = []
-        self._letter_negative = []
-        for rank in range(self.cs.nletters):
-            name = "l%02d" % (rank + 1)
-            self._letter_positive.append(
-                self.__loadBottom(name, color='black'))
-            name = "l%02d-n" % (rank + 1)
-            self._letter_negative.append(
-                self.__loadBottom(name, color='white'))
+        letter_negative = []
+        letter_positive = []
+        for c in self._letter_negative:
+            c = c.resize(xf, yf)
+            letter_negative.append(c)
+        self._letter_negative = letter_negative
+        for c in self._letter_positive:
+            c = c.resize(xf, yf)
+            letter_positive.append(c)
+        self._letter_positive = letter_positive
+
         self._createMissingImages()
         self.setNegative(neg)
         #
