@@ -344,7 +344,7 @@ class EditMenuDialog(LMenuDialog):  # Tools
         # und solitär wizard (-> custom games).
         '''
         tv.add_node(LTreeNode(
-            text='Solitaire &Wizard', command=self.menubar.mWizard))
+            text='Solitaire &Wizard...', command=self.menubar.mWizard))
         tv.add_node(LTreeNode(
                 text='Edit current game', command=self.menubar.mWizardEdit))
         '''
@@ -410,7 +410,7 @@ class GameMenuDialog(LMenuDialog):
         submenu.add_command(
             label=n_("Progression..."),
             command=lambda x: self.mPlayerStats(mode=107))
-        submenu = MfxMenu(menu, label=n_("D&emo statistics"))
+        submenu = MfxMenu(menu, label=n_("D&emo statistics..."))
         submenu.add_command(
             label=n_("Current game..."),
             command=lambda x: self.mPlayerStats(mode=1101))
@@ -450,9 +450,9 @@ class AssistMenuDialog(LMenuDialog):
         menu.add_command(
             label=n_("Demo (&all games)"), command=self.mMixedDemo)
         if USE_FREECELL_SOLVER:
-            menu.add_command(label=n_("&Solver"), command=self.mSolver)
+            menu.add_command(label=n_("&Solver..."), command=self.mSolver)
         else:
-            menu.add_command(label=n_("&Solver"), state='disabled')
+            menu.add_command(label=n_("&Solver..."), state='disabled')
         menu.add_separator()
         menu.add_command(
             label=n_("&Piles description"),
@@ -594,6 +594,11 @@ class OptionsMenuDialog(LMenuDialog):
                               self.menubar.tkopt.accordion_deal_all,
                               self.menubar.mOptAccordionDealAll)
 
+            self.addCheckNode(tv, rg,
+                              _('Auto-remove first card (in Pegged games)'),
+                              self.menubar.tkopt.accordion_deal_all,
+                              self.menubar.mOptPeggedAutoRemove)
+
             # submenu.add_separator()
 
         # -------------------------------------------
@@ -1253,6 +1258,7 @@ class PysolMenubarTk:
             mahjongg_show_removed=BooleanVar(),
             shisen_show_hint=BooleanVar(),
             accordion_deal_all=BooleanVar(),
+            pegged_auto_remove=BooleanVar(),
             sound=BooleanVar(),
             sound_sample_volume=IntVar(),
             sound_music_volume=IntVar(),
@@ -1315,6 +1321,7 @@ class PysolMenubarTk:
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
         tkopt.accordion_deal_all.set(opt.accordion_deal_all)
+        tkopt.pegged_auto_remove.set(opt.pegged_auto_remove)
         tkopt.sound.set(opt.sound)
         tkopt.sound_sample_volume.set(opt.sound_sample_volume)
         tkopt.sound_music_volume.set(opt.sound_music_volume)
@@ -2118,6 +2125,12 @@ the next time you restart the %(app)s""") % {'app': TITLE})
         self.app.opt.accordion_deal_all = self.tkopt.accordion_deal_all.get()
         # self.game.updateMenus()
 
+    def mOptPeggedAutoRemove(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.pegged_auto_remove = self.tkopt.pegged_auto_remove.get()
+        # self.game.updateMenus()
+
     def mOptCardset(self, *event):
         if self._cancelDrag(break_pause=False):
             return
