@@ -26,21 +26,23 @@
 import os
 import re
 
+from findcarddialog import connect_game_find_card_dialog, \
+        destroy_find_card_dialog
+
 import gtk
 from gtk import gdk
 
-# PySol imports
-from pysollib.mygettext import _
 from pysollib.gamedb import GI
+from pysollib.mygettext import _
 from pysollib.settings import TITLE
 
-# toolkit imports
-from soundoptionsdialog import SoundOptionsDialog
 from selectcardset import SelectCardsetDialogWithPreview
-from selecttile import SelectTileDialogWithPreview
+
 from selectgame import SelectGameDialogWithPreview
-from findcarddialog import connect_game_find_card_dialog, \
-        destroy_find_card_dialog
+
+from selecttile import SelectTileDialogWithPreview
+
+from soundoptionsdialog import SoundOptionsDialog
 
 
 def ltk2gtk(s):
@@ -456,12 +458,12 @@ class PysolMenubarTk:
     def _createSelectMenu(self, games, menu):
         assert isinstance(menu, gtk.Menu)
         self._addPopularGamesMenu(games, menu)
-        for l, d in (
+        for label, d in (
             (ltk2gtk('&French games'),   GI.SELECT_GAME_BY_TYPE),
             (ltk2gtk('&Oriental games'), GI.SELECT_ORIENTAL_GAME_BY_TYPE),
             (ltk2gtk('&Special games'),  GI.SELECT_SPECIAL_GAME_BY_TYPE),
                 ):
-            self._addGamesByType(games, menu, l, d)
+            self._addGamesByType(games, menu, label, d)
         self._addMahjonggGamesMenu(games, menu)
         sep = gtk.SeparatorMenuItem()
         menu.add(sep)
