@@ -243,6 +243,8 @@ class SelectGameData(SelectDialogTreeData):
                                lambda gi: gi.si.game_flags & GI.GT_CHILDREN),
                 SelectGameNode(None, _("Games with Scoring"),
                                lambda gi: gi.si.game_flags & GI.GT_SCORE),
+                SelectGameNode(None, _("Games with Stripped Decks"),
+                               lambda gi: gi.si.game_flags & GI.GT_STRIPPED),
                 SelectGameNode(
                     None, _("Games with Separate Decks"),
                     lambda gi: gi.si.game_flags & GI.GT_SEPARATE_DECKS),
@@ -487,7 +489,7 @@ class SelectGameDialogWithPreview(SelectGameDialog):
                 gamerandom=self.app.gamerandom,
                 gdb=self.app.gdb,
                 gimages=self.app.gimages,
-                images=self.app.subsampled_images,
+                images=None,
                 menubar=None,
                 miscrandom=self.app.miscrandom,
                 opt=self.app.opt.copy(),
@@ -503,6 +505,19 @@ class SelectGameDialogWithPreview(SelectGameDialog):
             self.preview_app.opt.shadow = 0
             self.preview_app.opt.shade = 0
         #
+
+        c = self.app.cardsets_cache.get(gi.category)
+        if not c:
+            cardset = self.app.cardset_manager.getByName(
+                self.app.opt.cardset[gi.category][0])
+            self.app.loadCardset(cardset, id=gi.category,
+                                 tocache=True, noprogress=True)
+            c = self.app.cardsets_cache.get(gi.category)
+        if c:
+            self.preview_app.images = c[2]
+        else:
+            self.preview_app.images = self.app.subsampled_images
+
         self.preview_app.audio = None    # turn off audio for initial dealing
         if animations >= 0:
             self.preview_app.opt.animations = animations
