@@ -21,26 +21,20 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
-import sys
 import time
-from six.moves import tkinter
-from six.moves import tkinter_font
 import traceback
 
-# PySol imports
+from pysollib.mfxutil import KwStruct, destruct, kwdefault, openURL
 from pysollib.mygettext import _
-from pysollib.mfxutil import destruct, kwdefault, KwStruct, openURL
 from pysollib.settings import WIN_SYSTEM
-
-# Toolkit imports
+from pysollib.ui.tktile.tkcanvas import MfxCanvas
 from pysollib.ui.tktile.tkutil import after, after_cancel
 from pysollib.ui.tktile.tkutil import bind, unbind_destroy
 from pysollib.ui.tktile.tkutil import makeToplevel, setTransient
-from pysollib.ui.tktile.tkcanvas import MfxCanvas
 
-if sys.version_info > (3,):
-    unicode = str
+import six
+from six.moves import tkinter
+from six.moves import tkinter_font
 
 # ************************************************************************
 # * abstract base class for the dialogs in this module
@@ -136,7 +130,7 @@ class MfxDialog:  # ex. _ToplevelDialog
 
     def altKeyEvent(self, event):
         key = event.char
-        key = unicode(key, 'utf-8')
+        key = six.text_type(key, 'utf-8')
         key = key.lower()
         button = self.accel_keys.get(key)
         if button is not None:
@@ -291,7 +285,7 @@ class MfxExceptionDialog(MfxMessageDialog):
                 (ex.errno, ex.strerror, repr(ex.filename))
         else:
             t = str(ex)
-        kw.text = text + unicode(t, errors='replace')
+        kw.text = text + six.text_type(t, errors='replace')
         MfxMessageDialog.__init__(self, parent, title, **kw.getKw())
 
 
