@@ -22,21 +22,37 @@ from six.moves import tkinter_tkfiledialog
 
 def createToolbarMenu(menubar, menu):
     tearoff = menu.cget('tearoff')
-#     data_dir = os.path.join(menubar.app.dataloader.dir, 'images', 'toolbar')
-#     submenu = MfxMenu(menu, label=n_('Style'), tearoff=tearoff)
-#     for f in os.listdir(data_dir):
-#         d = os.path.join(data_dir, f)
-#         if os.path.isdir(d) and os.path.exists(os.path.join(d, 'small')):
-#             name = f.replace('_', ' ').capitalize()
-#             submenu.add_radiobutton(
-#               label=name,
-#               variable=menubar.tkopt.toolbar_style,
-#               value=f, command=menubar.mOptToolbarStyle)
+    data_dir = os.path.join(menubar.app.dataloader.dir, 'images', 'toolbar')
+    submenu = MfxMenu(menu, label=n_('Icon Style'), tearoff=tearoff)
+    for f in os.listdir(data_dir):
+        d = os.path.join(data_dir, f)
+        if os.path.isdir(d) and os.path.exists(os.path.join(d, 'small')):
+            name = f.replace('_', ' ').capitalize()
+            submenu.add_radiobutton(
+              label=name,
+              variable=menubar.tkopt.toolbar_style,
+              value=f, command=menubar.mOptToolbarStyle)
+    submenu = MfxMenu(menu, label=n_('Icon Size'), tearoff=tearoff)
+    submenu.add_radiobutton(label=n_("Small icons"),
+                            variable=menubar.tkopt.toolbar_size, value=0,
+                            command=menubar.mOptToolbarSize)
+    submenu.add_radiobutton(label=n_("Large icons"),
+                            variable=menubar.tkopt.toolbar_size, value=1,
+                            command=menubar.mOptToolbarSize)
+    # submenu.add_radiobutton(label=n_("Extra large icons"),
+    #                         variable=menubar.tkopt.toolbar_size, value=2,
+    #                         command=menubar.mOptToolbarSize)
     submenu = MfxMenu(menu, label=n_('Compound'), tearoff=tearoff)
     for comp, label in COMPOUNDS:
         submenu.add_radiobutton(
             label=label, variable=menubar.tkopt.toolbar_compound,
             value=comp, command=menubar.mOptToolbarCompound)
+    submenu = MfxMenu(menu, label=n_('Visible buttons'), tearoff=tearoff)
+    for w in TOOLBAR_BUTTONS:
+        submenu.add_checkbutton(
+            label=_(w.capitalize()),
+            variable=menubar.tkopt.toolbar_vars[w],
+            command=lambda m=menubar, w=w: m.mOptToolbarConfig(w))
     menu.add_separator()
     menu.add_radiobutton(label=n_("Hide"),
                          variable=menubar.tkopt.toolbar, value=0,
@@ -53,20 +69,6 @@ def createToolbarMenu(menubar, menu):
     menu.add_radiobutton(label=n_("Right"),
                          variable=menubar.tkopt.toolbar, value=4,
                          command=menubar.mOptToolbar)
-    #  menu.add_separator()
-    #  menu.add_radiobutton(label=n_("Small icons"),
-    #                       variable=menubar.tkopt.toolbar_size, value=0,
-    #                       command=menubar.mOptToolbarSize)
-    #  menu.add_radiobutton(label=n_("Large icons"),
-    #                       variable=menubar.tkopt.toolbar_size, value=1,
-    #                       command=menubar.mOptToolbarSize)
-    menu.add_separator()
-    submenu = MfxMenu(menu, label=n_('Visible buttons'), tearoff=tearoff)
-    for w in TOOLBAR_BUTTONS:
-        submenu.add_checkbutton(
-            label=_(w.capitalize()),
-            variable=menubar.tkopt.toolbar_vars[w],
-            command=lambda m=menubar, w=w: m.mOptToolbarConfig(w))
 
 
 # ************************************************************************
@@ -170,11 +172,13 @@ class PysolMenubarTkCommon:
             mahjongg_show_removed=tkinter.BooleanVar(),
             shisen_show_hint=tkinter.BooleanVar(),
             accordion_deal_all=tkinter.BooleanVar(),
+            pegged_auto_remove=tkinter.BooleanVar(),
             sound=tkinter.BooleanVar(),
             auto_scale=tkinter.BooleanVar(),
             preserve_aspect_ratio=tkinter.BooleanVar(),
             spread_stacks=tkinter.BooleanVar(),
             center_layout=tkinter.BooleanVar(),
+            save_games_geometry=tkinter.BooleanVar(),
             cardback=tkinter.IntVar(),
             tabletile=tkinter.IntVar(),
             animations=tkinter.IntVar(),
@@ -184,6 +188,7 @@ class PysolMenubarTkCommon:
             shade=tkinter.BooleanVar(),
             shade_filled_stacks=tkinter.BooleanVar(),
             shrink_face_down=tkinter.BooleanVar(),
+            randomize_place=tkinter.BooleanVar(),
             toolbar=tkinter.IntVar(),
             toolbar_style=tkinter.StringVar(),
             toolbar_relief=tkinter.StringVar(),
@@ -192,7 +197,6 @@ class PysolMenubarTkCommon:
             statusbar=tkinter.BooleanVar(),
             num_cards=tkinter.BooleanVar(),
             helpbar=tkinter.BooleanVar(),
-            save_games_geometry=tkinter.BooleanVar(),
             splashscreen=tkinter.BooleanVar(),
             demo_logo=tkinter.BooleanVar(),
             mouse_type=tkinter.StringVar(),
@@ -222,14 +226,17 @@ class PysolMenubarTkCommon:
         tkopt.highlight_not_matching.set(opt.highlight_not_matching)
         tkopt.shrink_face_down.set(opt.shrink_face_down)
         tkopt.shade_filled_stacks.set(opt.shade_filled_stacks)
+        tkopt.randomize_place.set(opt.randomize_place)
         tkopt.mahjongg_show_removed.set(opt.mahjongg_show_removed)
         tkopt.shisen_show_hint.set(opt.shisen_show_hint)
         tkopt.accordion_deal_all.set(opt.accordion_deal_all)
+        tkopt.pegged_auto_remove.set(opt.pegged_auto_remove)
         tkopt.sound.set(opt.sound)
         tkopt.auto_scale.set(opt.auto_scale)
         tkopt.preserve_aspect_ratio.set(opt.preserve_aspect_ratio)
         tkopt.spread_stacks.set(opt.spread_stacks)
         tkopt.center_layout.set(opt.center_layout)
+        tkopt.save_games_geometry.set(opt.save_games_geometry)
         tkopt.cardback.set(self.app.cardset.backindex)
         tkopt.tabletile.set(self.app.tabletile_index)
         tkopt.animations.set(opt.animations)
@@ -246,7 +253,6 @@ class PysolMenubarTkCommon:
         tkopt.statusbar.set(opt.statusbar)
         tkopt.num_cards.set(opt.num_cards)
         tkopt.helpbar.set(opt.helpbar)
-        tkopt.save_games_geometry.set(opt.save_games_geometry)
         tkopt.demo_logo.set(opt.demo_logo)
         tkopt.splashscreen.set(opt.splashscreen)
         tkopt.mouse_type.set(opt.mouse_type)
@@ -325,6 +331,9 @@ class PysolMenubarTkCommon:
         menu.add_command(
             label=n_("Select game by nu&mber..."),
             command=self.mSelectGameById, accelerator=m+"M")
+        menu.add_command(
+            label=n_("Next game by num&ber"),
+            command=self.mNewGameWithNextId, accelerator=m+"N")
         menu.add_separator()
         submenu = MfxMenu(menu, label=n_("Fa&vorite games"))
         menu.add_command(label=n_("A&dd to favorites"), command=self.mAddFavor)
@@ -372,6 +381,11 @@ class PysolMenubarTkCommon:
             command=self.mRedo, accelerator="R")
         menu.add_command(label=n_("Redo &all"), command=self.mRedoAll)
 
+        menu.add_separator()
+        menu.add_command(
+            label=n_("Restart"),
+            command=self.mRestart, accelerator=m+"G")
+
         menu.add_separator()
         submenu = MfxMenu(menu, label=n_("&Set bookmark"))
         for i in range(9):
@@ -389,16 +403,13 @@ class PysolMenubarTkCommon:
         menu.add_command(
             label=n_("&Clear bookmarks"),
             command=self.mClearBookmarks)
-        menu.add_separator()
-
-        menu.add_command(
-            label=n_("Restart"),
-            command=self.mRestart, accelerator=m+"G")
 
         menu.add_separator()
-        menu.add_command(label=n_("Solitaire &Wizard"), command=self.mWizard)
         menu.add_command(
-            label=n_("&Edit current game"),
+            label=n_("Solitaire &Wizard..."),
+            command=self.mWizard)
+        menu.add_command(
+            label=n_("&Edit current game..."),
             command=self.mWizardEdit)
         menu.add_command(
             label=n_("&Delete current game"),
@@ -423,20 +434,19 @@ class PysolMenubarTkCommon:
         menu.add_command(
             label=n_("S&tatus..."),
             command=lambda: self.mPlayerStats(mode=100), accelerator=m+"Y")
-        menu.add_checkbutton(
-            label=n_("&Comments..."), variable=self.tkopt.comment,
-            command=self.mEditGameComment)
-        menu.add_separator()
         menu.add_command(
             label=n_("&Statistics..."),
             command=self.mPlayerStats, accelerator=m+"T")
+        menu.add_command(
+            label=n_("D&emo statistics..."),
+            command=lambda: self.mPlayerStats(mode=1101))
         menu.add_command(
             label=n_("Log..."),
             command=lambda: self.mPlayerStats(mode=103))
         menu.add_separator()
-        menu.add_command(
-            label=n_("D&emo statistics"),
-            command=lambda: self.mPlayerStats(mode=1101))
+        menu.add_checkbutton(
+            label=n_("&Comments..."), variable=self.tkopt.comment,
+            command=self.mEditGameComment)
 
         menu = MfxMenu(self.menubar, label=n_("&Assist"))
         menu.add_command(
@@ -446,7 +456,7 @@ class PysolMenubarTkCommon:
             label=n_("Highlight p&iles"),
             command=self.mHighlightPiles, accelerator="I")
         menu.add_command(
-            label=n_("&Find card"),
+            label=n_("&Find card..."),
             command=self.mFindCard, accelerator="F3")
         menu.add_separator()
         menu.add_command(
@@ -456,9 +466,9 @@ class PysolMenubarTkCommon:
             label=n_("Demo (&all games)"),
             command=self.mMixedDemo)
         if USE_FREECELL_SOLVER:
-            menu.add_command(label=n_("&Solver"), command=self.mSolver)
+            menu.add_command(label=n_("&Solver..."), command=self.mSolver)
         else:
-            menu.add_command(label=n_("&Solver"), state='disabled')
+            menu.add_command(label=n_("&Solver..."), state='disabled')
         menu.add_separator()
         menu.add_command(
             label=n_("&Piles description"),
@@ -470,7 +480,7 @@ class PysolMenubarTkCommon:
         menu = MfxMenu(self.menubar, label=n_("&Options"))
         menu.add_command(
             label=n_("&Player options..."),
-            command=self.mOptPlayerOptions)
+            command=self.mOptPlayerOptions, accelerator=m+'P')
         submenu = MfxMenu(menu, label=n_("&Automatic play"))
         submenu.add_checkbutton(
             label=n_("Auto &face up"), variable=self.tkopt.autofaceup,
@@ -527,6 +537,10 @@ class PysolMenubarTkCommon:
             label=n_("&Deal all cards (in Accordion type games)"),
             variable=self.tkopt.accordion_deal_all,
             command=self.mOptAccordionDealAll)
+        submenu.add_checkbutton(
+            label=n_("A&uto-remove first card (in Pegged games)"),
+            variable=self.tkopt.pegged_auto_remove,
+            command=self.mOptPeggedAutoRemove)
         menu.add_separator()
         label = n_("&Sound...")
         menu.add_command(
@@ -558,6 +572,10 @@ class PysolMenubarTkCommon:
             submenu.add_checkbutton(
                 label=n_("&Center layout"), variable=self.tkopt.center_layout,
                 command=self.mOptCenterLayout)
+            submenu.add_checkbutton(
+                label=n_("Save games &geometry"),
+                variable=self.tkopt.save_games_geometry,
+                command=self.mOptSaveGamesGeometry)
         # manager = self.app.cardset_manager
         # n = manager.len()
         menu.add_command(
@@ -587,6 +605,10 @@ class PysolMenubarTkCommon:
             label=n_("Shade &filled stacks"),
             variable=self.tkopt.shade_filled_stacks,
             command=self.mOptShadeFilledStacks)
+        submenu.add_checkbutton(
+            label=n_("&Randomize card placement"),
+            variable=self.tkopt.randomize_place,
+            command=self.mOptRandomizePlace)
         submenu = MfxMenu(menu, label=n_("A&nimations"))
         submenu.add_radiobutton(
             label=n_("&None"), variable=self.tkopt.animations, value=0,
@@ -652,11 +674,6 @@ class PysolMenubarTkCommon:
         submenu.add_checkbutton(
             label=n_("Show &help bar"), variable=self.tkopt.helpbar,
             command=self.mOptHelpbar)
-        # if not USE_PIL:
-        menu.add_checkbutton(
-            label=n_("Save games &geometry"),
-            variable=self.tkopt.save_games_geometry,
-            command=self.mOptSaveGamesGeometry)
         menu.add_checkbutton(
             label=n_("&Demo logo"), variable=self.tkopt.demo_logo,
             command=self.mOptDemoLogo)
@@ -686,10 +703,16 @@ class PysolMenubarTkCommon:
         menu.add_command(
             label=n_("&Rules for this game"),
             command=self.mHelpRules, accelerator="F1")
+        menu.add_separator()
+        menu.add_command(
+            label=n_("What's &new?"),
+            command=self.mHelpNews)
+        menu.add_command(
+            label=n_("R&eport a Bug"),
+            command=self.mHelpReportBug)
         menu.add_command(
             label=n_("&License terms"),
             command=self.mHelpLicense)
-        # menu.add_command(label=n_("What's &new ?"), command=self.mHelpNews)
         if WIN_SYSTEM != "aqua":
             menu.add_separator()
             menu.add_command(
@@ -865,9 +888,15 @@ class PysolMenubarTkCommon:
     def _addSelectMahjonggGameSubMenu(self, games, menu, command, variable):
         def select_func(gi):
             return gi.si.game_type == GI.GT_MAHJONGG
+
+        def sort_func(gi):
+            return gi.short_name
+
         mahjongg_games = list(filter(select_func, games))
         if len(mahjongg_games) == 0:
             return
+
+        mahjongg_games.sort(key=sort_func)
         #
         menu = MfxMenu(menu, label=n_("&Mahjongg games"))
 
@@ -945,7 +974,7 @@ class PysolMenubarTkCommon:
         self.updateGamesMenu(submenu, games)
 
     def _addSelectAllGameSubMenu(self, games, menu, command, variable):
-        if menu.name != "allgamesbyname":
+        if menu.name == "select":
             menu = MfxMenu(menu, label=n_("&All games by name"))
         n, d = 0, self.cb_max
         i = 0
@@ -1473,6 +1502,12 @@ Unsupported game for import.
         self.app.opt.accordion_deal_all = self.tkopt.accordion_deal_all.get()
         # self.game.updateMenus()
 
+    def mOptPeggedAutoRemove(self, *args):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.pegged_auto_remove = self.tkopt.pegged_auto_remove.get()
+        # self.game.updateMenus()
+
     def _updateCardSize(self):
         geom = (self.app.canvas.winfo_width(),
                 self.app.canvas.winfo_height())
@@ -1577,6 +1612,17 @@ Unsupported game for import.
         self.app.opt.center_layout = not self.app.opt.center_layout
         self._updateCardSize()
 
+    def mOptRandomizePlace(self, *event):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.randomize_place = self.tkopt.randomize_place.get()
+        self._updateCardSize()
+
+    def mOptSaveGamesGeometry(self, *event):
+        if self._cancelDrag(break_pause=False):
+            return
+        self.app.opt.save_games_geometry = self.tkopt.save_games_geometry.get()
+
     def _mOptCardback(self, index):
         if self._cancelDrag(break_pause=False):
             return
@@ -1674,11 +1720,6 @@ Unsupported game for import.
         if self.app.helpbar.show(show, resize=resize):
             self.top.update_idletasks()
 
-    def mOptSaveGamesGeometry(self, *event):
-        if self._cancelDrag(break_pause=False):
-            return
-        self.app.opt.save_games_geometry = self.tkopt.save_games_geometry.get()
-
     def mOptDemoLogo(self, *event):
         if self._cancelDrag(break_pause=False):
             return
